pub fn print_versions_table(versions: Vec<FileVersion>, limit: usize)Expand description
Prints a formatted table of file versions to stdout, showing the last limit entries.
pub fn print_versions_table(versions: Vec<FileVersion>, limit: usize)Prints a formatted table of file versions to stdout, showing the last limit entries.